* ================== Program: PQI_AREA_RISKADJ.SAS ==================;
*
*       Title:  AREA LEVEL RISK ADJUSTED RATES FOR AHRQ 
*               PREVENTION QUALITY INDICATORS
*
*  Description:
*         USES PROC SCORE TO CALCULATE RISK-ADJUSTED RATES FOR
*         PREVENTION QUALITY INDICATORS ACROSS STRATIFIERS.
*         OUTPUT STRATIFIED BY AGE, SEXCAT AND POVCAT FROM
*         POPULATION FILE AND PQI_ALL_MEASURES OUTPUT.
*         VARIABLES CREATED BY THIS PROGRAM ARE EAPQxx, RAPQxx, 
*         LAPQxx, UAPQxx, SAPQxx, XAPQxx
*
*                >>> AHRQ QI ICD-09  VERSION 6.0.2 <<<
*                   >>> VERSION DATE JULY 2017<<<
*====================================================================;

*PATHNAME specifies the location of the PQI folder which includes 
          Programs, SASdata, and Macros subfolders;
%LET PATHNAME=c:\pathname;                        *<==USER MUST modify;
filename CONTROL "&PATHNAME.\PQI\Programs\PQI_ALL_CONTROL.SAS"; 
%include CONTROL; 

 * ------------------------------------------------------------------ ;
* --- PREVENTION QUALITY INDICATOR (PQI) NAMING CONVENTION:       --- ;
* --- THE FIRST LETTER IDENTIFIES THE PREVENTION QUALITY          --- ;
* --- INDICATOR AS ONE OF THE FOLLOWING:
            (T) NUMERATOR ("TOP") - FROM PQI_ALL_MEASURES
            (P) DENOMINATOR ("POP") - ADJUSTED FROM POPULATION FILE
            (O) OBSERVED RATES (T/P)
            (E) EXPECTED RATE
            (R) RISK-ADJUSTED RATE
            (L) LOWER CONFIDENCE LIMIT FOR RISK-ADJUSTED RATE
            (U) UPPER CONFIDENCE LIMIT FOR RISK-ADJUSTED RATE
            (S) SMOOTHED RATE (NOT REPORTED FOR STRATA)
            (X) SMOOTHED RATE STANDARD ERROR (NOT REPORTED FOR STRATA)
* --- THE SECOND LETTER IDENTIFIES THE PQI AS AREA (A) LEVEL     --- ;
* --- INDICATOR.  THE NEXT TWO CHARACTERS ARE ALWAYS 'PQ'.       --- ;
* --- THE LAST TWO DIGITS ARE THE INDICATOR NUMBER               --- ;
* ------------------------------------------------------------------ ;


/*MACRO TO ADJUST AREA AGGREGATION BASED ON MAREA VALUE IN PQI_ALL_CONTROL.*/
 %MACRO CTY2MA;
    %IF &MALEVL EQ 0 %THEN %DO;
        attrib MAREA length=$5
          label='FIPS STATE COUNTY CODE';
        MAREA = FIPSTCO;
    %END;
    %ELSE %IF &MALEVL EQ 1 %THEN %DO;
        attrib MAREA length=$5
          label='MODIFIED FIPS';
        MAREA = input(put(FIPSTCO,$M1AREA.),$5.);
    %END;
    %ELSE %IF &MALEVL EQ 2 %THEN %DO;
        attrib MAREA length=$5
          label='OMB 1999 METRO AREA';
        MAREA = input(put(FIPSTCO,$M2AREA.),$5.);
    %END;
    %ELSE %IF &MALEVL EQ 3 %THEN %DO;
        attrib MAREA length=$5
          label='OMB 2003 METRO AREA';
        MAREA = input(put(FIPSTCO,$M3AREA.),$5.);
    %END;
 %MEND;

 title2 'PROGRAM PQI_AREA_RISKADJ PART I';
 title3 'AHRQ PREVENTION QUALITY INDICATORS: CALCULATE ADJUSTED AREA RATES';

 * ---------------------------------------------------------------- ;
 * --- ADD POPULATION DENOMINATOR                               --- ;
 * --- THIS STEP DETERMINES WHICH AREAS ARE INCLUDED IN THE     --- ;
 * --- OUTPUT FROM PQI_ALL_MEASURES.                            --- ;
 * ---------------------------------------------------------------- ;

 data TEMP0 (keep=MAREA);
 set    OUTMSR.&OUTFILE_MEAS.;

 %CTY2MA

 run;

 /* IDENTIFY UNIQUE MAREA VALUES IN PQI_ALL_MEASURES OUTPUT. */
 proc   Sort data=TEMP0 OUT=MAREA NODUPKEY;
 by     MAREA;
 run;

  /* LOAD POPULATION FOR MAREA LEVEL AND YEAR IN PQI_ALL_CONTROL. */
 data QIPOP0;
    length FIPSTCO $5 SEXCAT POPCAT AGECAT RACECAT 3 
           POP_1995 POP_1996 POP_1997 POP_1998 POP_1999
           POP_2000 POP_2001 POP_2002 POP_2003 POP_2004
           POP_2005 POP_2006 POP_2007 POP_2008 POP_2009
           POP_2010 POP_2011 POP_2012 POP_2013 POP_2014
           POP_2015 POP 8;

    infile POPFILE missover FIRSTOBS=2;

    input FIPSTCO SEXCAT POPCAT RACECAT 
          POP_1995 POP_1996 POP_1997 POP_1998 POP_1999
          POP_2000 POP_2001 POP_2002 POP_2003 POP_2004
          POP_2005 POP_2006 POP_2007 POP_2008 POP_2009
          POP_2010 POP_2011 POP_2012 POP_2013 POP_2014
          POP_2015;

    %CTY2MA

    if POPCAT in (1,2,3,4)            then AGECAT = 0;
    else if POPCAT in (5,6,7,8)       then AGECAT = 1;
    else if POPCAT in (9,10,11,12,13) then AGECAT = 2;
    else if POPCAT in (14,15)         then AGECAT = 3;
    else                                   AGECAT = 4;

    POP = POP_&POPYEAR.;

 run;

 proc   SUMMARY data=QIPOP0 NWAY;
 class  MAREA POPCAT AGECAT SEXCAT RACECAT;
 var    POP;
 output OUT=QIPOP SUM=;
 run;

 proc   Sort data=QIPOP;
 by     MAREA POPCAT AGECAT SEXCAT RACECAT;
 run;

 data   QIPOP(keep=MAREA POPCAT AGECAT SEXCAT RACECAT POP);
 merge  MAREA(in=X) QIPOP(in=Y);
 by     MAREA;

 if X and Y;

 run;

 * -------------------------------------------------------------- ;
 * --- PREVENTION QUALITY INDICATORS ADJUSTED RATES ------------- ;
 * -------------------------------------------------------------- ;
 * AREA-LEVEL INDICATOR DENOMINATORS ARE ADJUSTED BASED ON THE    *
 * COMBINATION OF COUNTY, AGE, SEX, AND RACE IN THE NUMERATOR.    *
 * THE MOD3 MACRO ITERATES THROUGH EACH MEASURE IN THE            *
 * PQI_ALL_MEASURES OUTPUT AND REDUCES THE AREA POPULATION BY THE *
 * NUMERATOR TOTAL. THE AREA POPULATION TOTALS ARE THEN ADJUSTED  *
 * BASED ON THE MEASURE RELAVENT POPULATION. ONLY VALID AREA      *
 * CODES ARE RETURNED. THE MOD3 MACRO INPUTS ARE:                 *
 * --- N - AREA MEASURE NUMBER                                --- *
 * --- PQ - THE PREVENTION QUALITY INDICATOR NAME WITHOUT THE --- *
 *          PREFIX (A)                                        --- ;
 * --- DL - INDICATE IF POPULATION IS NOT ADJUSTED (PQ02)    ---  ;
 * -------------------------------------------------------------- ;

 %MACRO MOD3(N,PQ,DL);

 * --- THIS SET CREATES TEMP1 WHICH CONTAINS THE DEPENDENT    --- ;
 * --- VARIABLE (TPQ) AND INDEPENDENT VARIABLES USED IN       --- ;
 * --- REGRESSION.  IT APPENDS TO THE DISCHARGE DATA ONE      --- ;
 * --- OBSERVATION PER MAREA AND DEMOGRAPHIC GROUP.           --- ;

 %IF &DL. = 0 %THEN %DO;

 data   TEMP_2;
 set    OUTMSR.&OUTFILE_MEAS. (keep=KEY FIPSTCO T&PQ. POPCAT AGECAT SEXCAT RACECAT);

 if T&PQ. in (1);

 %CTY2MA

 run;

  /* SUM THE NUMERATOR 'T' FLAGS BY MAREA POPCAT AGECAT SEXCAT RACECAT. */
 proc   SUMMARY data=TEMP_2 NWAY;
 class  MAREA POPCAT AGECAT SEXCAT RACECAT;
 var    T&PQ.;
 output OUT=TEMP_3 N=TCOUNT;
 run;

 proc   Sort data=TEMP_3;
 by     MAREA POPCAT AGECAT SEXCAT RACECAT;
 run;

  /* REDUCE THE DENOMINATOR POPULATION BY THE SUM OF THE NUMERATOR COUNT. */

 data   TEMP_4(DROP=TCOUNT);
 merge  QIPOP(in=X keep=MAREA POPCAT AGECAT SEXCAT RACECAT POP) 
        TEMP_3(keep=MAREA POPCAT AGECAT SEXCAT RACECAT TCOUNT);
 by     MAREA POPCAT AGECAT SEXCAT RACECAT;

 if X;

 if TCOUNT > 0 then PCOUNT = POP - TCOUNT;
 else PCOUNT = POP;

 if PCOUNT < 0 then PCOUNT = 0;

 if AGECAT in (0) then PCOUNT = 0;

 N = &N.;

 if N in (5) and AGECAT in (1) then PCOUNT = 0;
 if N in (15) and AGECAT in (2,3,4) then PCOUNT = 0;


 if PCOUNT = 0 then delete;

 run;

 /* FOR NUMERATOR, RETAIN ONLY RECORDS WITH A VALID MAREA CODE. */

 data   TEMP_3(DROP=POP);
 merge  TEMP_3(in=X keep=MAREA POPCAT AGECAT SEXCAT RACECAT TCOUNT)
        QIPOP(keep=MAREA POPCAT AGECAT SEXCAT RACECAT POP);
 by     MAREA POPCAT AGECAT SEXCAT RACECAT;

 if X;

 if POP < 0 then PCOUNT = 0;
 else if TCOUNT > 0 then PCOUNT = TCOUNT;
 else PCOUNT = 0;

 if PCOUNT = 0 then delete;

 run;

 /* COMBINE THE NUMERATOR AND DENOMINATOR */;

 data   TEMP1;
 set    TEMP_3(in=X) TEMP_4;

 if X then T&PQ. = 1;
 else T&PQ. = 0;

 run;

 %END;
 %ELSE %DO;

 data   TEMP_2;
 set    OUTMSR.&OUTFILE_MEAS.(keep=KEY FIPSTCO T&PQ. POPCAT AGECAT SEXCAT RACECAT);

 if T&PQ. in (0,1);

 %CTY2MA

 run;

 proc   SUMMARY data=TEMP_2 NWAY;
 class  T&PQ. MAREA POPCAT AGECAT SEXCAT RACECAT;
 var    T&PQ.;
 output OUT=TEMP_3 N=TCOUNT;
 run;

 proc   Sort data=TEMP_3;
 by     MAREA POPCAT AGECAT SEXCAT RACECAT;
 run;

 /* RETAIN ONLY RECORDS WITH A VALID FIPS CODE */;

 data   TEMP1;
 merge  TEMP_3(IN=X keep=MAREA POPCAT AGECAT SEXCAT RACECAT TCOUNT T&PQ.)
        QIPOP(keep=MAREA POPCAT AGECAT SEXCAT RACECAT POP);
 by     MAREA POPCAT AGECAT SEXCAT RACECAT;

 if X;

 if POP < 0 then PCOUNT = 0;
 else if TCOUNT > 0 then PCOUNT = TCOUNT;
 else PCOUNT = 0;

 N = &N.;

 if N in (2) and AGECAT in (0) then PCOUNT = 0;
 if N in (9) and AGECAT in (1,2,3,4) then PCOUNT = 0;

 if PCOUNT = 0 then delete;

 run;

 %END;

 data   TEMP1;
 length FEMALE AGECAT1-AGECAT14 FAGECAT1-FAGECAT14 
        POVCAT1-POVCAT10 3;
 set    TEMP1;

 if SEXCAT in (2) then FEMALE = 1;
 else FEMALE = 0;

 array ARRY1{14} AGECAT1-AGECAT14;
 array ARRY2{14} FAGECAT1-FAGECAT14;

 do I = 1 TO 14;
    ARRY1(I) = 0; ARRY2(I) = 0;
 end;

 N = &N.;

 if N NOTIN (9) then ARRY1(POPCAT-4) = 1;
 if N NOTIN (9) then ARRY2(POPCAT-4) = FEMALE;

 array ARRY3{10} POVCAT1-POVCAT10;

 do I = 1 TO 10;
    ARRY3(I) = 0;
 end;

 PVIDX = put(MAREA,$POVCAT.);

 if PVIDX > 0 then ARRY3(PVIDX) = 1;

 run;

 * --- THIS DATA STEP READS THE REGRESSION COEFFICIENTS FOR EACH --- ;
 * --- COVARIATE.                                                --- ;

 data   TEMP2(keep=INTERCEP FEMALE AGECAT1-AGECAT14 FAGECAT1-FAGECAT14
                   POVCAT1-POVCAT10  
                   _NAME_ _TYPE_ _LINK_ _LNLIKE_ _STATUS_);
 length INTERCEP FEMALE AGECAT1-AGECAT14 FAGECAT1-FAGECAT14
        POVCAT1-POVCAT10 _LNLIKE_ 8
        _NAME_ _TYPE_ _LINK_ $8 _STATUS_ $11;

 %IF &USE_SES=0 %THEN %DO ;
    infile COVAR missover lrecl=1500;
 %END ;
 %ELSE %DO;
    infile COVARSES missover lrecl=1500;
 %END ;

 input  N INTERCEP FEMALE AGECAT1-AGECAT14 FAGECAT1-FAGECAT14
        POVCAT1-POVCAT10  
        _NAME_ _TYPE_ _LINK_ _LNLIKE_ _STATUS_;

 if N = &N.;

 run;

 * --- THIS STEP CALCULATES A PREDICTED PREVENTION QUALITY INDICATOR BY  --- ;
 * --- MULTIPLYING THE STRATIFIED NUMERATOR AND DENOMINATOR TOTALS BY    --- ;
 * --- THE MEASURE COEFFICIENTS FROM THE COVARIATES FILE.                --- ;

 proc   SCORE data=TEMP1 SCORE=TEMP2 TYPE=PARMS OUT=TEMP1Y;
 var    FEMALE AGECAT1-AGECAT14 FAGECAT1-FAGECAT14
        POVCAT1-POVCAT10;
 run;

 %let dsid=%sysfunc(open(temp1y));
 %let dnum=%sysfunc(attrn(&dsid,nobs));
 %let drc=%sysfunc(close(&dsid));

 %if &dnum ne 0 %then %do;

 data   TEMP1Y;
 set    TEMP1Y;

 EHAT = EXP(MHAT)/(1 + EXP(MHAT));
 PHAT = EHAT * (1 - EHAT);
 ONE = 1;

 run;

 proc   SUMMARY data=TEMP1Y;
 class  MAREA AGECAT SEXCAT RACECAT;
 var    T&PQ. EHAT PHAT ONE;
 output OUT=R&PQ. SUM(T&PQ. EHAT PHAT ONE)=T&PQ. EHAT PHAT P&PQ.;
 WEIGHT PCOUNT;
 run;

 data   R&PQ.(keep=MAREA AGECAT SEXCAT RACECAT _TYPE_
                   E&PQ. R&PQ. L&PQ. U&PQ. S&PQ. X&PQ.);
 set    R&PQ.;

 if _TYPE_ &TYPELVLA;

 * --- Switch signal variance based on USE_SES flag --- ;
 %IF &USE_SES = 0 %THEN %DO ;
   %include MacLib(PQI_AREA_SIGVAR_ARRAY.SAS);
 %END ; 
 %ELSE %DO ;
   %include MacLib(PQI_AREA_SIGVAR_ARRAY_SES.SAS);
 %END ;

 if &N. = 1 then SUB_N = 1;
 if &N. = 2 then SUB_N = 2;
 if &N. = 3 then SUB_N = 3;
 if &N. = 5 then SUB_N = 4;
 if &N. = 7 then SUB_N = 5;
 if &N. = 8 then SUB_N = 6;
 if &N. = 10 then SUB_N = 7;
 if &N. = 11 then SUB_N = 8;
 if &N. = 12 then SUB_N = 9;
 if &N. = 14 then SUB_N = 10;
 if &N. = 15 then SUB_N = 11;
 if &N. = 16 then SUB_N = 12;
 if &N. = 90 then SUB_N = 13;
 if &N. = 91 then SUB_N = 14;
 if &N. = 92 then SUB_N = 15;
 if &N. = 93 then SUB_N = 16;

 E&PQ. = EHAT / P&PQ.;
 THAT = T&PQ. / P&PQ.;
 
 if _TYPE_ in (0,8) then do;
    R&PQ.   = (THAT / E&PQ.) * ARRYA3(SUB_N);
    SE&PQ.  = (ARRYA3(SUB_N) / E&PQ.) * (1 / P&PQ.) * SQRT(PHAT);
    VAR&PQ. = SE&PQ.**2;
    SN&PQ.  = ARRYA2(SUB_N) / (ARRYA2(SUB_N) + VAR&PQ.);
    S&PQ.   = (R&PQ. * SN&PQ.) + ((1 -  SN&PQ.) * ARRYA3(SUB_N));
    X&PQ.   = SQRT(ARRYA2(SUB_N)- (SN&PQ. * ARRYA2(SUB_N)));
 end;
 else do;
    R&PQ.   = (THAT / E&PQ.);
    SE&PQ.  = (1 / E&PQ.) * (1 / P&PQ.) * SQRT(PHAT);
    S&PQ.   = .;
    X&PQ.   = .;
 end;

 L&PQ.   = R&PQ. - (1.96 * SE&PQ.);
 if L&PQ. < 0 then L&PQ. = 0;
 U&PQ.   = R&PQ. + (1.96 * SE&PQ.);


 if _TYPE_ in (0,8) then do;  
     if L&PQ. > 1 then L&PQ. = 1; 
     if U&PQ. > 1 then U&PQ. = 1;
     if R&PQ. > 1 then R&PQ. = 1;
 end;

 run;

 %end;
 %else %do;

 data   R&PQ.;
    MAREA='';AGECAT=.;SEXCAT=.;RACECAT=.;_TYPE_=0;E&PQ=.;R&PQ=.;L&PQ=.;U&PQ=.;S&PQ=.;X&PQ=.;
    output;
 run;
 
 %end;


 proc Sort data=R&PQ.;
   by MAREA AGECAT SEXCAT RACECAT;
 run; quit;

 proc   DATASETS NOLIST;
 delete TEMP1 TEMP1Y TEMP2;
 run;

 %MEND;

 %MOD3(1,APQ01,0);
 %MOD3(2,APQ02,1);
 %MOD3(3,APQ03,0);
 %MOD3(5,APQ05,0);
 %MOD3(7,APQ07,0);
 %MOD3(8,APQ08,0);
 %MOD3(10,APQ10,0);
 %MOD3(11,APQ11,0);
 %MOD3(12,APQ12,0);
 %MOD3(14,APQ14,0);
 %MOD3(15,APQ15,0);
 %MOD3(16,APQ16,0);
 %MOD3(90,APQ90,0);
 %MOD3(91,APQ91,0);
 %MOD3(92,APQ92,0);
 %MOD3(93,APQ93,0);

 * --- MERGES THE MAREA ADJUSTED RATES FOR EACH PREVENTION QUALITY--- ;
 * --- INDICATOR.  PREFIX FOR THE ADJUSTED RATES IS R(Risk        --- ;
 * --- Adjusted).                                                 --- ;

 data   RISKADJ;
 merge  RAPQ01(keep=MAREA AGECAT SEXCAT RACECAT EAPQ01 RAPQ01 LAPQ01 UAPQ01 SAPQ01 XAPQ01)
        RAPQ02(keep=MAREA AGECAT SEXCAT RACECAT EAPQ02 RAPQ02 LAPQ02 UAPQ02 SAPQ02 XAPQ02)
        RAPQ03(keep=MAREA AGECAT SEXCAT RACECAT EAPQ03 RAPQ03 LAPQ03 UAPQ03 SAPQ03 XAPQ03)
        RAPQ05(keep=MAREA AGECAT SEXCAT RACECAT EAPQ05 RAPQ05 LAPQ05 UAPQ05 SAPQ05 XAPQ05)
        RAPQ07(keep=MAREA AGECAT SEXCAT RACECAT EAPQ07 RAPQ07 LAPQ07 UAPQ07 SAPQ07 XAPQ07)
        RAPQ08(keep=MAREA AGECAT SEXCAT RACECAT EAPQ08 RAPQ08 LAPQ08 UAPQ08 SAPQ08 XAPQ08)
        RAPQ10(keep=MAREA AGECAT SEXCAT RACECAT EAPQ10 RAPQ10 LAPQ10 UAPQ10 SAPQ10 XAPQ10)
        RAPQ11(keep=MAREA AGECAT SEXCAT RACECAT EAPQ11 RAPQ11 LAPQ11 UAPQ11 SAPQ11 XAPQ11)
        RAPQ12(keep=MAREA AGECAT SEXCAT RACECAT EAPQ12 RAPQ12 LAPQ12 UAPQ12 SAPQ12 XAPQ12)      
        RAPQ14(keep=MAREA AGECAT SEXCAT RACECAT EAPQ14 RAPQ14 LAPQ14 UAPQ14 SAPQ14 XAPQ14)
        RAPQ15(keep=MAREA AGECAT SEXCAT RACECAT EAPQ15 RAPQ15 LAPQ15 UAPQ15 SAPQ15 XAPQ15)
        RAPQ16(keep=MAREA AGECAT SEXCAT RACECAT EAPQ16 RAPQ16 LAPQ16 UAPQ16 SAPQ16 XAPQ16)
        RAPQ90(keep=MAREA AGECAT SEXCAT RACECAT EAPQ90 RAPQ90 LAPQ90 UAPQ90 SAPQ90 XAPQ90)
        RAPQ91(keep=MAREA AGECAT SEXCAT RACECAT EAPQ91 RAPQ91 LAPQ91 UAPQ91 SAPQ91 XAPQ91)
        RAPQ92(keep=MAREA AGECAT SEXCAT RACECAT EAPQ92 RAPQ92 LAPQ92 UAPQ92 SAPQ92 XAPQ92)
        RAPQ93(keep=MAREA AGECAT SEXCAT RACECAT EAPQ93 RAPQ93 LAPQ93 UAPQ93 SAPQ93 XAPQ93);
 by     MAREA AGECAT SEXCAT RACECAT;

 label
 EAPQ01 = 'PQI 01 Diabetes Short-Term Complications Admission Rate (Expected)'
 EAPQ02 = 'PQI 02 Perforated Appendix Admission Rate (Expected)'
 EAPQ03 = 'PQI 03 Diabetes Long-Term Complications Admission Rate (Expected)'
 EAPQ05 = 'PQI 05 Chronic Obstructive Pulmonary Disease (COPD) or Asthma in Older Adults Admission Rate (Expected)'
 EAPQ07 = 'PQI 07 Hypertension Admission Rate (Expected)'
 EAPQ08 = 'PQI 08 Heart Failure Admission Rate (Expected)'
 EAPQ10 = 'PQI 10 Dehydration Admission Rate (Expected)'
 EAPQ11 = 'PQI 11 Bacterial Pneumonia Admission Rate (Expected)'
 EAPQ12 = 'PQI 12 Urinary Tract Infection Admission Rate (Expected)'
 EAPQ14 = 'PQI 14 Uncontrolled Diabetes Admission Rate (Expected)'
 EAPQ15 = 'PQI 15 Asthma in Younger Adults Admission Rate (Expected)'
 EAPQ16 = 'PQI 16 Lower-Extremity Amputation among Patients with Diabetes Rate (Expected)'
 EAPQ90 = 'PQI 90 Prevention Quality Overall Composite (Expected)'
 EAPQ91 = 'PQI 91 Prevention Quality Acute Composite (Expected)'
 EAPQ92 = 'PQI 92 Prevention Quality Chronic Composite (Expected)'
 EAPQ93 = 'PQI 93 Prevention Quality Diabetes Composite (Expected)'
 ;

 label
 RAPQ01 = 'PQI 01 Diabetes Short-Term Complications Admission Rate (Risk Adj)'
 RAPQ02 = 'PQI 02 Perforated Appendix Admission Rate (Risk Adj)'
 RAPQ03 = 'PQI 03 Diabetes Long-Term Complications Admission Rate (Risk Adj)'
 RAPQ05 = 'PQI 05 Chronic Obstructive Pulmonary Disease (COPD) or Asthma in Older Adults Admission Rate (Risk Adj)'
 RAPQ07 = 'PQI 07 Hypertension Admission Rate (Risk Adj)'
 RAPQ08 = 'PQI 08 Heart Failure Admission Rate (Risk Adj)'
 RAPQ10 = 'PQI 10 Dehydration Admission Rate (Risk Adj)'
 RAPQ11 = 'PQI 11 Bacterial Pneumonia Admission Rate (Risk Adj)'
 RAPQ12 = 'PQI 12 Urinary Tract Infection Admission Rate (Risk Adj)'
 RAPQ14 = 'PQI 14 Uncontrolled Diabetes Admission Rate (Risk Adj)'
 RAPQ15 = 'PQI 15 Asthma in Younger Adults Admission Rate (Risk Adj)'
 RAPQ16 = 'PQI 16 Lower-Extremity Amputation among Patients with Diabetes Rate (Risk Adj)'
 RAPQ90 = 'PQI 90 Prevention Quality Overall Composite (Risk Adj)'
 RAPQ91 = 'PQI 91 Prevention Quality Acute Composite (Risk Adj)'
 RAPQ92 = 'PQI 92 Prevention Quality Chronic Composite (Risk Adj)'
 RAPQ93 = 'PQI 93 Prevention Quality Diabetes Composite (Risk Adj)'
 ;

 label
 LAPQ01 = 'PQI 01 Diabetes Short-Term Complications Admission Rate (Lower CL)'
 LAPQ02 = 'PQI 02 Perforated Appendix Admission Rate (Lower CL)'
 LAPQ03 = 'PQI 03 Diabetes Long-Term Complications Admission Rate (Lower CL)'
 LAPQ05 = 'PQI 05 Chronic Obstructive Pulmonary Disease (COPD) or Asthma in Older Adults Admission Rate (Lower CL)'
 LAPQ07 = 'PQI 07 Hypertension Admission Rate (Lower CL)'
 LAPQ08 = 'PQI 08 Heart Failure Admission Rate (Lower CL)'
 LAPQ10 = 'PQI 10 Dehydration Admission Rate (Lower CL)'
 LAPQ11 = 'PQI 11 Bacterial Pneumonia Admission Rate (Lower CL)'
 LAPQ12 = 'PQI 12 Urinary Tract Infection Admission Rate (Lower CL)'
 LAPQ14 = 'PQI 14 Uncontrolled Diabetes Admission Rate (Lower CL)'
 LAPQ15 = 'PQI 15 Asthma in Younger Adults Admission Rate (Lower CL)'
 LAPQ16 = 'PQI 16 Lower-Extremity Amputation among Patients with Diabetes Rate (Lower CL)'
 LAPQ90 = 'PQI 90 Prevention Quality Overall Composite (Lower CL)'
 LAPQ91 = 'PQI 91 Prevention Quality Acute Composite (Lower CL)'
 LAPQ92 = 'PQI 92 Prevention Quality Chronic Composite (Lower CL)'
 LAPQ93 = 'PQI 93 Prevention Quality Diabetes Composite (Lower CL)'
 ;

 label
 UAPQ01 = 'PQI 01 Diabetes Short-Term Complications Admission Rate (Upper CL)'
 UAPQ02 = 'PQI 02 Perforated Appendix Admission Rate (Upper CL)'
 UAPQ03 = 'PQI 03 Diabetes Long-Term Complications Admission Rate (Upper CL)'
 UAPQ05 = 'PQI 05 Chronic Obstructive Pulmonary Disease (COPD) or Asthma in Older Adults Admission Rate (Upper CL)'
 UAPQ07 = 'PQI 07 Hypertension Admission Rate (Upper CL)'
 UAPQ08 = 'PQI 08 Heart Failure Admission Rate (Upper CL)'
 UAPQ10 = 'PQI 10 Dehydration Admission Rate (Upper CL)'
 UAPQ11 = 'PQI 11 Bacterial Pneumonia Admission Rate (Upper CL)'
 UAPQ12 = 'PQI 12 Urinary Tract Infection Admission Rate (Upper CL)'
 UAPQ14 = 'PQI 14 Uncontrolled Diabetes Admission Rate (Upper CL)'
 UAPQ15 = 'PQI 15 Asthma in Younger Adults Admission Rate (Upper CL)'
 UAPQ16 = 'PQI 16 Lower-Extremity Amputation among Patients with Diabetes Rate (Upper CL)'
 UAPQ90 = 'PQI 90 Prevention Quality Overall Composite (Upper CL)'
 UAPQ91 = 'PQI 91 Prevention Quality Acute Composite (Upper CL)'
 UAPQ92 = 'PQI 92 Prevention Quality Chronic Composite (Upper CL)'
 UAPQ93 = 'PQI 93 Prevention Quality Diabetes Composite (Upper CL)'
 ;

 label
 SAPQ01 = 'PQI 01 Diabetes Short-Term Complications Admission Rate (Smoothed)'
 SAPQ02 = 'PQI 02 Perforated Appendix Admission Rate (Smoothed)'
 SAPQ03 = 'PQI 03 Diabetes Long-Term Complications Admission Rate (Smoothed)'
 SAPQ05 = 'PQI 05 Chronic Obstructive Pulmonary Disease (COPD) or Asthma in Older Adults Admission Rate (Smoothed)'
 SAPQ07 = 'PQI 07 Hypertension Admission Rate (Smoothed)'
 SAPQ08 = 'PQI 08 Heart Failure Admission Rate (Smoothed)'
 SAPQ10 = 'PQI 10 Dehydration Admission Rate (Smoothed)'
 SAPQ11 = 'PQI 11 Bacterial Pneumonia Admission Rate (Smoothed)'
 SAPQ12 = 'PQI 12 Urinary Tract Infection Admission Rate (Smoothed)'
 SAPQ14 = 'PQI 14 Uncontrolled Diabetes Admission Rate (Smoothed)'
 SAPQ15 = 'PQI 15 Asthma in Younger Adults Admission Rate (Smoothed)'
 SAPQ16 = 'PQI 16 Lower-Extremity Amputation among Patients with Diabetes Rate (Smoothed)'
 SAPQ90 = 'PQI 90 Prevention Quality Overall Composite (Smoothed)'
 SAPQ91 = 'PQI 91 Prevention Quality Acute Composite (Smoothed)'
 SAPQ92 = 'PQI 92 Prevention Quality Chronic Composite (Smoothed)'
 SAPQ93 = 'PQI 93 Prevention Quality Diabetes Composite (Smoothed)'
 ;

 label
 XAPQ01 = 'PQI 01 Diabetes Short-Term Complications Admission Rate (Smthe SE)'
 XAPQ02 = 'PQI 02 Perforated Appendix Admission Rate (Smthe SE)'
 XAPQ03 = 'PQI 03 Diabetes Long-Term Complications Admission Rate (Smthe SE)'
 XAPQ05 = 'PQI 05 Chronic Obstructive Pulmonary Disease (COPD) or Asthma in Older Adults Admission Rate (Smthe SE)'
 XAPQ07 = 'PQI 07 Hypertension Admission Rate (Smthe SE)'
 XAPQ08 = 'PQI 08 Heart Failure Admission Rate (Smthe SE)'
 XAPQ10 = 'PQI 10 Dehydration Admission Rate (Smthe SE)'
 XAPQ11 = 'PQI 11 Bacterial Pneumonia Admission Rate (Smthe SE)'
 XAPQ12 = 'PQI 12 Urinary Tract Infection Admission Rate (Smthe SE)'
 XAPQ14 = 'PQI 14 Uncontrolled Diabetes Admission Rate (Smthe SE)'
 XAPQ15 = 'PQI 15 Asthma in Younger Adults Admission Rate (Smthe SE)'
 XAPQ16 = 'PQI 16 Lower-Extremity Amputation among Patients with Diabetes Rate (Smthe SE)'
 XAPQ90 = 'PQI 90 Prevention Quality Overall Composite (Smthe SE)'
 XAPQ91 = 'PQI 91 Prevention Quality Acute Composite (Smthe SE)'
 XAPQ92 = 'PQI 92 Prevention Quality Chronic Composite (Smthe SE)'
 XAPQ93 = 'PQI 93 Prevention Quality Diabetes Composite (Smthe SE)'
 ;

 run;

*=======================================================================;
*  Title:  PROGRAM PQI_AREA_RISKADJ  PART II:  MERGE AREA RATES FOR AHRQ
*          PREVENTION QUALITY INDICATORS
*
*  Description:  MERGE RATES FOR PREVENTION QUALITY INDICATORS
*
*              >>> AHRQ QI ICD-09  VERSION 6.0.2 <<<
*                >>> VERSION DATE APRIL, 2016<<<
*=======================================================================;

 title2 'PROGRAM PQI_AREA_RISKADJ  PART II';
 title3 'AHRQ PREVENTION QUALITY INDICATORS:  AREA-LEVEL MERGED FILES';

 * ---------------------------------------------------------------- ;
 * --- PREVENTION QUALITY INDICATOR MERGED RATES                --- ;
 * ---------------------------------------------------------------- ;

 data   OUTARISK.&OUTFILE_AREARISK.;
 merge  OUTAOBS.&OUTFILE_AREAOBS.(
            keep=MAREA AGECAT SEXCAT RACECAT _TYPE_ 
                 TAPQ01-TAPQ03 TAPQ05 TAPQ07-TAPQ08 TAPQ10-TAPQ12 TAPQ14-TAPQ16 TAPQ90-TAPQ93
                 PAPQ01-PAPQ03 PAPQ05 PAPQ07-PAPQ08 PAPQ10-PAPQ12 PAPQ14-PAPQ16 PAPQ90-PAPQ93 
                 OAPQ01-OAPQ03 OAPQ05 OAPQ07-OAPQ08 OAPQ10-OAPQ12 OAPQ14-OAPQ16 OAPQ90-OAPQ93)
        RISKADJ(
            keep=MAREA AGECAT SEXCAT RACECAT
                 EAPQ01-EAPQ03 EAPQ05 EAPQ07-EAPQ08 EAPQ10-EAPQ12 EAPQ14-EAPQ16 EAPQ90-EAPQ93
                 RAPQ01-RAPQ03 RAPQ05 RAPQ07-RAPQ08 RAPQ10-RAPQ12 RAPQ14-RAPQ16 RAPQ90-RAPQ93
                 LAPQ01-LAPQ03 LAPQ05 LAPQ07-LAPQ08 LAPQ10-LAPQ12 LAPQ14-LAPQ16 LAPQ90-LAPQ93
                 UAPQ01-UAPQ03 UAPQ05 UAPQ07-UAPQ08 UAPQ10-UAPQ12 UAPQ14-UAPQ16 UAPQ90-UAPQ93
                 SAPQ01-SAPQ03 SAPQ05 SAPQ07-SAPQ08 SAPQ10-SAPQ12 SAPQ14-SAPQ16 SAPQ90-SAPQ93
                 XAPQ01-XAPQ03 XAPQ05 XAPQ07-XAPQ08 XAPQ10-XAPQ12 XAPQ14-XAPQ16 XAPQ90-XAPQ93);
 by     MAREA AGECAT SEXCAT RACECAT;

 array ARRY1{16} EAPQ01-EAPQ03 EAPQ05 EAPQ07-EAPQ08 EAPQ10-EAPQ12 EAPQ14-EAPQ16 EAPQ90-EAPQ93;
 array ARRY2{16} RAPQ01-RAPQ03 RAPQ05 RAPQ07-RAPQ08 RAPQ10-RAPQ12 RAPQ14-RAPQ16 RAPQ90-RAPQ93;
 array ARRY3{16} LAPQ01-LAPQ03 LAPQ05 LAPQ07-LAPQ08 LAPQ10-LAPQ12 LAPQ14-LAPQ16 LAPQ90-LAPQ93;
 array ARRY4{16} UAPQ01-UAPQ03 UAPQ05 UAPQ07-UAPQ08 UAPQ10-UAPQ12 UAPQ14-UAPQ16 UAPQ90-UAPQ93;
 array ARRY5{16} SAPQ01-SAPQ03 SAPQ05 SAPQ07-SAPQ08 SAPQ10-SAPQ12 SAPQ14-SAPQ16 SAPQ90-SAPQ93;
 array ARRY6{16} XAPQ01-XAPQ03 XAPQ05 XAPQ07-XAPQ08 XAPQ10-XAPQ12 XAPQ14-XAPQ16 XAPQ90-XAPQ93;
 array ARRY7{16} PAPQ01-PAPQ03 PAPQ05 PAPQ07-PAPQ08 PAPQ10-PAPQ12 PAPQ14-PAPQ16 PAPQ90-PAPQ93;

 do I = 1 TO 16;
   if ARRY7(I) <= 2 then do;
      ARRY1(I) = .; ARRY2(I) = .; ARRY3(I) = .; ARRY4(I) = .;
      ARRY5(I) = .; ARRY6(I) = .; 
   end;
 end;

 DROP I;

 format EAPQ01 EAPQ02 EAPQ03 EAPQ05 EAPQ07 EAPQ08 EAPQ10 EAPQ11 EAPQ12 
        EAPQ14 EAPQ15 EAPQ16 EAPQ90 EAPQ91 EAPQ92 EAPQ93
        LAPQ01 LAPQ02 LAPQ03 LAPQ05 LAPQ07 LAPQ08 LAPQ10 LAPQ11 LAPQ12
        LAPQ14 LAPQ15 LAPQ16 LAPQ90 LAPQ91 LAPQ92 LAPQ93
        OAPQ01 OAPQ02 OAPQ03 OAPQ05 OAPQ07 OAPQ08 OAPQ10 OAPQ11 OAPQ12
        OAPQ14 OAPQ15 OAPQ16 OAPQ90 OAPQ91 OAPQ92 OAPQ93
        RAPQ01 RAPQ02 RAPQ03 RAPQ05 RAPQ07 RAPQ08 RAPQ10 RAPQ11 RAPQ12
        RAPQ14 RAPQ15 RAPQ16 RAPQ90 RAPQ91 RAPQ92 RAPQ93
        SAPQ01 SAPQ02 SAPQ03 SAPQ05 SAPQ07 SAPQ08 SAPQ10 SAPQ11 SAPQ12
        SAPQ14 SAPQ15 SAPQ16 SAPQ90 SAPQ91 SAPQ92 SAPQ93
        UAPQ01 UAPQ02 UAPQ03 UAPQ05 UAPQ07 UAPQ08 UAPQ10 UAPQ11 UAPQ12
        UAPQ14 UAPQ15 UAPQ16 UAPQ90 UAPQ91 UAPQ92 UAPQ93
        XAPQ01 XAPQ02 XAPQ03 XAPQ05 XAPQ07 XAPQ08 XAPQ10 XAPQ11 XAPQ12
        XAPQ14 XAPQ15 XAPQ16 XAPQ90 XAPQ91 XAPQ92 XAPQ93 13.7
        TAPQ01 TAPQ02 TAPQ03 TAPQ05 TAPQ07 TAPQ08 TAPQ10 TAPQ11 TAPQ12
        TAPQ14 TAPQ15 TAPQ16 TAPQ90 TAPQ91 TAPQ92 TAPQ93 
        PAPQ01 PAPQ02 PAPQ03 PAPQ05 PAPQ07 PAPQ08 PAPQ10 PAPQ11 PAPQ12
        PAPQ14 PAPQ15 PAPQ16 PAPQ90 PAPQ91 PAPQ92 PAPQ93 13.0;

 run;

 * ---------------------------------------------------------------- ;
 * --- CONTENTS AND MEANS OF MAREA MERGED MEANS FILE            --- ;
 * ---------------------------------------------------------------- ;

 proc Contents data=OUTARISK.&OUTFILE_AREARISK. POSITION;
 run;

 proc Means data=OUTARISK.&OUTFILE_AREARISK.(WHERE=(_TYPE_ in (8))) N NMISS MIN MAX MEAN SUM NOLABELS;
 title4 'SUMMARY OF AREA-LEVEL RATES (_TYPE_=8)';
 run;

 * ---------------------------------------------------------------- ;
 * --- PRINT AREA MERGED MEANS FILE                             --- ;
 * ---------------------------------------------------------------- ;

 %MACRO PRT2;

 %IF &PRINT. = 1 %THEN %DO;

 %MACRO PRT(PQ,TEXT);

 proc  PRINT data=OUTARISK.&OUTFILE_AREARISK. label SPLIT='*';
 var   MAREA AGECAT SEXCAT RACECAT 
       TAPQ&PQ. PAPQ&PQ. OAPQ&PQ. EAPQ&PQ. RAPQ&PQ. LAPQ&PQ. UAPQ&PQ. SAPQ&PQ. XAPQ&PQ.;
 label MAREA    = "MAREA"
       AGECAT   = "AGECAT"
       SEXCAT   = "SEXCAT"
       RACECAT  = "RACECAT"
       TAPQ&PQ. = "TAPQ&PQ.*(Numerator)"
       PAPQ&PQ. = "PAPQ&PQ.*(Denominator)"
       OAPQ&PQ. = "OAPQ&PQ.*(Observed)"
       EAPQ&PQ. = "EAPQ&PQ.*(Expected)"
       RAPQ&PQ. = "RAPQ&PQ.*(Risk Adj)"
       LAPQ&PQ. = "LAPQ&PQ.*(Lower CL)"
       UAPQ&PQ. = "UAPQ&PQ.*(Upper CL)"
       SAPQ&PQ. = "SAPQ&PQ.*(Smoothed)"
       XAPQ&PQ. = "XAPQ&PQ.*(Smthe SE)"
       ;

 format AGECAT AGECAT.   
        SEXCAT SEXCAT.
        RACECAT RACECAT.
      TAPQ&PQ. PAPQ&PQ. COMMA13.0
        OAPQ&PQ. EAPQ&PQ. RAPQ&PQ. LAPQ&PQ. UAPQ&PQ. SAPQ&PQ. XAPQ&PQ. 8.6;

 title4 "FINAL OUTPUT";
 title5 "Indicator  &PQ.: &TEXT";

 run;

 %MEND PRT;

 %PRT(01,Diabetes Short-Term Complications Admission Rate);
 %PRT(02,Perforated Appendix Admission Rate);
 %PRT(03,Diabetes Long-Term Complications Admission Rate);
 %PRT(05,Chronic Obstructive Pulmonary Disease (COPD) or Asthma in Older Adults Admission Rate);
 %PRT(07,Hypertension Admission Rate);
 %PRT(08,Heart Failure Admission Rate);
 %PRT(10,Dehydration Admission Rate);
 %PRT(11,Bacterial Pneumonia Admission Rate);
 %PRT(12,Urinary Tract Infection Admission Rate);
 %PRT(14,Uncontrolled Diabetes Admission Rate);
 %PRT(15,Asthma in Younger Adults Admission Rate);
 %PRT(16,Lower-Extremity Amputation among Patients with Diabetes Rate);
 %PRT(90,Prevention Quality Overall Composite);
 %PRT(91,Prevention Quality Acute Composite);
 %PRT(92,Prevention Quality Chronic Composite);
 %PRT(93,Prevention Quality Diabetes Composite);

 %END;

 %MEND PRT2 ;

 %PRT2;

 * ---------------------------------------------------------------- ;
 * --- WRITE SAS OUTPUT DATA SET TO TEXT FILE                   --- ;
 * ---------------------------------------------------------------- ;

 %MACRO TEXT;

 %IF &TXTARISK. = 1  %THEN %DO;
	%LET TYPEARN  = %sysfunc(tranwrd(&TYPELVLA.,%str(,),_));
	%LET TYPEARN2  = %sysfunc(compress(&TYPEARN.,'(IN )'));
	%let PQCSVREF  = %sysfunc(pathname(PQTXTARA));
	%let PQCSVRF2 =  %sysfunc(tranwrd(&PQCSVREF.,.TXT,_&TYPEARN2..TXT));

 data _NULL_;
 set OUTARISK.&OUTFILE_AREARISK;
 FILE "&PQCSVRF2." lrecl=2000;
 if _N_=1 then do;
 
  put "MAREA" "," "Age"  "," "Sex"  "," "Race"  "," "Type" ","
 "TAPQ01" "," "TAPQ02" "," "TAPQ03" "," 
 "TAPQ05" "," "TAPQ07" "," "TAPQ08" ","
 "TAPQ10" "," "TAPQ11" "," "TAPQ12" ","
 "TAPQ14" "," "TAPQ15" "," "TAPQ16" ","
 "TAPQ90" "," "TAPQ91" "," "TAPQ92" "," "TAPQ93" ","
 "PAPQ01" "," "PAPQ02" "," "PAPQ03" "," 
 "PAPQ05" "," "PAPQ07" "," "PAPQ08" ","
 "PAPQ10" "," "PAPQ11" "," "PAPQ12" ","
 "PAPQ14" "," "PAPQ15" "," "PAPQ16" ","
 "PAPQ90" "," "PAPQ91" "," "PAPQ92" "," "PAPQ93" ","
 "OAPQ01" "," "OAPQ02" "," "OAPQ03" "," 
 "OAPQ05" "," "OAPQ07" "," "OAPQ08" ","
 "OAPQ10" "," "OAPQ11" "," "OAPQ12" ","
 "OAPQ14" "," "OAPQ15" "," "OAPQ16" ","
 "OAPQ90" "," "OAPQ91" "," "OAPQ92" "," "OAPQ93" ","
 "EAPQ01" "," "EAPQ02" "," "EAPQ03" "," 
 "EAPQ05" "," "EAPQ07" "," "EAPQ08" ","
 "EAPQ10" "," "EAPQ11" "," "EAPQ12" "," 
 "EAPQ14" "," "EAPQ15" "," "EAPQ16" ","
 "EAPQ90" "," "EAPQ91" "," "EAPQ92" "," "EAPQ93" ","
 "RAPQ01" "," "RAPQ02" "," "RAPQ03" "," 
 "RAPQ05" "," "RAPQ07" "," "RAPQ08" ","
 "RAPQ10" "," "RAPQ11" "," "RAPQ12" "," 
 "RAPQ14" "," "RAPQ15" "," "RAPQ16" ","
 "RAPQ90" "," "RAPQ91" "," "RAPQ92" "," "RAPQ93" ","
 "LAPQ01" "," "LAPQ02" "," "LAPQ03" "," 
 "LAPQ05" "," "LAPQ07" "," "LAPQ08" ","
 "LAPQ10" "," "LAPQ11" "," "LAPQ12" "," 
 "LAPQ14" "," "LAPQ15" "," "LAPQ16" ","
 "LAPQ90" "," "LAPQ91" "," "LAPQ92" "," "LAPQ93" ","
 "UAPQ01" "," "UAPQ02" "," "UAPQ03" "," 
 "UAPQ05" "," "UAPQ07" "," "UAPQ08" ","
 "UAPQ10" "," "UAPQ11" "," "UAPQ12" "," 
 "UAPQ14" "," "UAPQ15" "," "UAPQ16" ","
 "UAPQ90" "," "UAPQ91" "," "UAPQ92" "," "UAPQ93" ","
 "SAPQ01" "," "SAPQ02" "," "SAPQ03" "," 
 "SAPQ05" "," "SAPQ07" "," "SAPQ08" ","
 "SAPQ10" "," "SAPQ11" "," "SAPQ12" "," 
 "SAPQ14" "," "SAPQ15" "," "SAPQ16" ","
 "SAPQ90" "," "SAPQ91" "," "SAPQ92" "," "SAPQ93" ","
 "XAPQ01" "," "XAPQ02" "," "XAPQ03" "," 
 "XAPQ05" "," "XAPQ07" "," "XAPQ08" ","
 "XAPQ10" "," "XAPQ11" "," "XAPQ12" ","
 "XAPQ14" "," "XAPQ15" "," "XAPQ16" ","
 "XAPQ90" "," "XAPQ91" "," "XAPQ92" "," "XAPQ93"
 ;
 end;
 
 put MAREA  $5. "," AGECAT 3. "," SEXCAT 3. "," RACECAT 3.  "," _TYPE_ 2.  ","
 (TAPQ01-TAPQ03 TAPQ05 TAPQ07-TAPQ08 TAPQ10-TAPQ12 TAPQ14-TAPQ16 TAPQ90-TAPQ93) (7.0 ",")
  ","
 (PAPQ01-PAPQ03 PAPQ05 PAPQ07-PAPQ08 PAPQ10-PAPQ12 PAPQ14-PAPQ16 PAPQ90-PAPQ93) (13.2 ",")
 ","
 (OAPQ01-OAPQ03 OAPQ05 OAPQ07-OAPQ08 OAPQ10-OAPQ12 OAPQ14-OAPQ16 OAPQ90-OAPQ93) (12.10 ",")
 ","
 (EAPQ01-EAPQ03 EAPQ05 EAPQ07-EAPQ08 EAPQ10-EAPQ12 EAPQ14-EAPQ16 EAPQ90-EAPQ93) (12.10 ",")
 ","
 (RAPQ01-RAPQ03 RAPQ05 RAPQ07-RAPQ08 RAPQ10-RAPQ12 RAPQ14-RAPQ16 RAPQ90-RAPQ93) (12.10 ",")
 ","
 (LAPQ01-LAPQ03 LAPQ05 LAPQ07-LAPQ08 LAPQ10-LAPQ12 LAPQ14-LAPQ16 LAPQ90-LAPQ93) (12.10 ",")
 ","
 (UAPQ01-UAPQ03 UAPQ05 UAPQ07-UAPQ08 UAPQ10-UAPQ12 UAPQ14-UAPQ16 UAPQ90-UAPQ93) (12.10 ",")
 ","
 (SAPQ01-SAPQ03 SAPQ05 SAPQ07-SAPQ08 SAPQ10-SAPQ12 SAPQ14-SAPQ16 SAPQ90-SAPQ93) (12.10 ",")
 ","
 (XAPQ01-XAPQ03 XAPQ05 XAPQ07-XAPQ08 XAPQ10-XAPQ12 XAPQ14-XAPQ16 XAPQ90-XAPQ93) (12.10 ",")
 ;
 run;

 %END;

 %MEND TEXT;

 %TEXT;
